scinumtools.math package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   scinumtools.math.solver

Module contents
---------------

.. automodule:: scinumtools.math
   :members:
   :undoc-members:
   :show-inheritance:
